# Versioning, Support, and Deprecation Policy

Mismo is currently in alpha and breaking changes may happen at any time.
In the future, we will follow the ideas outlines below:

Mismo considers everything documented in these docs to be part of the public API.
If it's not in the docs, breaking changes may happen at any time.

Mismo follows [NEP29](https://numpy.org/neps/nep-0029-deprecation_policy.html)
for python version support.
